% CLASS: AMPState
% 
% HIERARCHY (Enumeration of the various super- and subclasses)
%   Superclasses: N/A
%   Subclasses: N/A
% 
% TYPE (Abstract or Concrete)
%   Concrete
%
% DESCRIPTION (High-level overview of the class)
%   This class is used to store information about the "state" of AMP-MMV
%   after execution, which is useful if one wishes to run AMP-MMV again
%   using a different configuration, since it allows AMP-MMV to be
%   "warm-started" from the previous message states.  Objects of this class
%   are returned by the various AMP-MMV implementations, and can be used as
%   inputs (see Options.m) to AMP-MMV for the purpose of warm-starting.
%
% PROPERTIES (State variables)
%   * All properties of this class are hidden, and should not require user
%   access or manipulation *
%
% METHODS (Subroutines/functions)
%   * All methods of this class are hidden *
% 

%
% Coded by: Justin Ziniel, The Ohio State Univ.
% E-mail: zinielj@ece.osu.edu
% Last change: 12/29/11
% Change summary: 
%       - Created from AMPState v1.0 (12/29/11; JAZ)
% Version 1.1
%

classdef AMPState

    properties (GetAccess = private, SetAccess = immutable, Hidden)
        C_STATE;
        Z_State;
        MU_STATE;
        ETA_FWD;
        ETA_BWD;
        KAPPA_FWD;
        KAPPA_BWD;
        PI_IN;
        PI_OUT;
    end
    
    methods (Hidden)
        % Constructor
        function obj = AMPState(C_STATE, Z_State, MU_STATE, ETA_FWD, ...
                ETA_BWD, KAPPA_FWD, KAPPA_BWD, PI_IN, PI_OUT)
            obj.C_STATE = C_STATE;
            obj.Z_State = Z_State;
            obj.MU_STATE = MU_STATE;
            obj.ETA_FWD = ETA_FWD;
            obj.ETA_BWD = ETA_BWD;
            obj.KAPPA_FWD = KAPPA_FWD;
            obj.KAPPA_BWD = KAPPA_BWD;
            obj.PI_IN = PI_IN;
            obj.PI_OUT = PI_OUT;
        end
        
        % Accessor
        function [C_STATE, Z_State, MU_STATE, ETA_FWD, ...
                ETA_BWD, KAPPA_FWD, KAPPA_BWD, PI_IN, PI_OUT] = ...
                getState(obj)
            C_STATE = obj.C_STATE;
            Z_State = obj.Z_State;
            MU_STATE = obj.MU_STATE;
            ETA_FWD = obj.ETA_FWD;
            ETA_BWD = obj.ETA_BWD;
            KAPPA_FWD = obj.KAPPA_FWD;
            KAPPA_BWD = obj.KAPPA_BWD;
            PI_IN = obj.PI_IN;
            PI_OUT = obj.PI_OUT;
        end
        
    end % methods
    
end % classdef