% PRODUCE_PLOTS     Produce plots for CHANGING_MTX_TEST
%

%
% Coded by: Justin Ziniel, The Ohio State Univ.
% E-mail: zinielj@ece.osu.edu
% Last change: 12/29/11
% Change summary: 
%		- Created from produce_plots v1.0 (12/29/11; JAZ)
% Version 1.1
%

clear; clc

%% Load a results file

uiload

%% Produce the plots

algs = {'AMP-MMV', 'SKS'};    % Algorithms
suffix = {'MPI', 'SKS'};
marker = {'-ko', '--r+', '-k^'};

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot of the NMSE for each approach
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Compute the trial-averaged failure rate, MSE, Jaccard index, TNMSE, and 
% runtime statistics for each algorithm
for a = 1:N_alpha
    for b = 1:N_beta
        for g = 1:numel(algs)
            % First identify those data points that are not NaNs, which may
            % be different for different algs. since MPI-MMV and SKS may be
            % averaged over more realizations
            eval(['inds = find(~isnan(TNMSE_' suffix{g} '(a,b,:)));']);
            
            % Compute the ensemble average over the non-NaN trials
            eval(['mean_NSER_' suffix{g} '(a,b) = mean(NSER_' suffix{g} ...
                '(a,b,inds), 3);']);
            eval(['mean_TNMSE_' suffix{g} '(a,b) = mean(TNMSE_' suffix{g} ...
                '(a,b,inds), 3);']);
            eval(['mean_Run_' suffix{g} '(a,b) = mean(Run_' suffix{g} ...
                '(a,b,inds), 3);']);
            if strcmp('AMP-MMV', algs{g})
                eval(['mean_NSER2_' suffix{g} '(a,b) = mean(NSER2_' suffix{g} ...
                    '(a,b,inds), 3);']);
            end
            % Keep track of the # of realizations averaged over
            eval(['N_trials_' suffix{g} '(a,b) = numel(inds);'])
        end
    end
end


% Plot the Jaccard index, TNMSE, and runtime for each algorithm at each
% choice of alpha
for a = 1:N_alpha
    % Clear existing figure
    figure(a); clf;
    
    plot_inds = find(beta_sweep > 1e-3);
    
    subplot(1, 3, 2); hold on; set(gca, 'XScale', 'log', 'YScale', 'log')
    for g = 1:numel(algs)
        if ~strcmp(suffix{g}, 'SKS')
            plot(beta_sweep(plot_inds), eval(['mean_NSER_' suffix{g} '(a,plot_inds)']), marker{g})
        end
    end
    plot(beta_sweep(plot_inds), mean_NSER2_MPI(a,plot_inds), marker{end});
    hold off; grid on; axis square
    title(sprintf(['\\alpha = %1.2g  |  N = %d, M = %d, T = %d, \\lambda = %1.3f, SNR = %g dB'], ...
        alpha_sweep(a), N, M, T, lambda, SNRdB)); axis tight
    xlabel('Innovation Rate, \beta'); ylabel('Normalized Support Error Rate (NSER)')
    legend({algs{1}, 'AMP-MMV [p(s_n|{\bf y})]'}, 'Location', 'Best')
    
    subplot(1, 3, 1); hold on; set(gca, 'XScale', 'log')
    for g = 1:numel(algs)
        plot(beta_sweep(plot_inds), 10*log10(eval(['mean_TNMSE_' suffix{g} '(a,plot_inds)'])), marker{g})
    end
    hold off; grid on; axis square
    title(sprintf(['\\alpha = %1.2g  |  N = %d, M = %d, T = %d, \\lambda = %1.3f, SNR = %g dB'], ...
        alpha_sweep(a), N, M, T, lambda, SNRdB)); axis tight
    xlabel('Innovation Rate, \beta'); ylabel('Timestep-Averaged Normalized MSE (TNMSE) [dB]')
    legend(algs, 'Location', 'Best')
    
    subplot(1, 3, 3); hold on; set(gca, 'XScale', 'log', 'YScale', 'log')
    for g = 1:numel(algs)
        if ~strcmp(suffix{g}, 'SKS')
            semilogy(beta_sweep(plot_inds), eval(['mean_Run_' suffix{g} '(a,plot_inds)']), marker{g})
        end
    end
    hold off; grid on; axis square
    title(sprintf(['\\alpha = %1.2g  |  N = %d, M = %d, T = %d, \\lambda = %1.3f, SNR = %g dB'], ...
        alpha_sweep(a), N, M, T, lambda, SNRdB)); axis tight
    xlabel('Innovation Rate, \beta'); ylabel('Runtime [s]')
    legend(algs, 'Location', 'Best')
end